@@ -97,6 +97,9 @@ class Link extends Nette\Object
 			return (string) $this->component->link($this->destination, $this->params);
 
 		} catch (\Exception $e) {
+			if (func_num_args()) {
+				throw $e;
+			}
 			trigger_error("Exception in " . __METHOD__ . "(): {$e->getMessage()} in {$e->getFile()}:{$e->getLine()}", E_USER_ERROR);
 		}
 	}
