@@ -64,6 +64,9 @@ class ActiveRow implements \IteratorAggregate, IRow
 		try {
 			return (string) $this->getPrimary();
 		} catch (\Exception $e) {
+			if (func_num_args()) {
+				throw $e;
+			}
 			trigger_error("Exception in " . __METHOD__ . "(): {$e->getMessage()} in {$e->getFile()}:{$e->getLine()}", E_USER_ERROR);
 		}
 	}
@@ -284,7 +287,7 @@ class ActiveRow implements \IteratorAggregate, IRow
 		} catch(MissingReferenceException $e) {}
 
 		$this->removeAccessColumn($key);
-		throw new Nette\MemberAccessException("Cannot read an undeclared column \"$key\".");
+		throw new Nette\MemberAccessException("Cannot read an undeclared column '$key'.");
 	}
 
 
