@@ -42,7 +42,7 @@ abstract class TextBase extends BaseControl
 		if ($value === NULL) {
 			$value = '';
 		} elseif (!is_scalar($value) && !method_exists($value, '__toString')) {
-			throw new Nette\InvalidArgumentException('Value must be scalar or NULL, ' . gettype($value) . ' given.');
+			throw new Nette\InvalidArgumentException(sprintf("Value must be scalar or NULL, %s given in field '%s'.", gettype($value), $this->name));
 		}
 		$this->rawValue = $this->value = $value;
 		return $this;
@@ -117,7 +117,9 @@ abstract class TextBase extends BaseControl
 	{
 		if ($operation === Form::LENGTH || $operation === Form::MAX_LENGTH) {
 			$tmp = is_array($arg) ? $arg[1] : $arg;
-			$this->control->maxlength = is_scalar($tmp) ? $tmp : NULL;
+			if (is_scalar($tmp)) {
+				$this->control->maxlength = isset($this->control->maxlength) ? min($this->control->maxlength, $tmp) : $tmp;
+			}
 		}
 		return parent::addRule($operation, $message, $arg);
 	}
@@ -127,8 +129,7 @@ abstract class TextBase extends BaseControl
 
 
 	/**
-	 * Email validator: is control's value valid email address?
-	 * @param  TextBase
+	 * Is control's value valid email address?
 	 * @return bool
 	 */
 	public static function validateEmail(TextBase $control)
@@ -138,8 +139,7 @@ abstract class TextBase extends BaseControl
 
 
 	/**
-	 * URL validator: is control's value valid URL?
-	 * @param  TextBase
+	 * Is control's value valid URL?
 	 * @return bool
 	 */
 	public static function validateUrl(TextBase $control)
@@ -175,9 +175,7 @@ abstract class TextBase extends BaseControl
 
 
 	/**
-	 * Regular expression validator: matches control's value regular expression?
-	 * @param  TextBase
-	 * @param  string
+	 * Matches control's value regular expression?
 	 * @return bool
 	 */
 	public static function validatePattern(TextBase $control, $pattern)
@@ -187,8 +185,7 @@ abstract class TextBase extends BaseControl
 
 
 	/**
-	 * Integer validator: is a control's value decimal number?
-	 * @param  TextBase
+	 * Is a control's value decimal number?
 	 * @return bool
 	 */
 	public static function validateInteger(TextBase $control)
@@ -204,8 +201,7 @@ abstract class TextBase extends BaseControl
 
 
 	/**
-	 * Float validator: is a control's value float number?
-	 * @param  TextBase
+	 * Is a control's value float number?
 	 * @return bool
 	 */
 	public static function validateFloat(TextBase $control)
