@@ -74,6 +74,7 @@ class Form extends Container
 	const DATA_TEXT = 1;
 	const DATA_LINE = 2;
 	const DATA_FILE = 3;
+	const DATA_KEYS = 8;
 
 	/** @internal tracker ID */
 	const TRACKER_ID = '_form_';
@@ -529,7 +530,7 @@ class Form extends Container
 	public function getAllErrors()
 	{
 		trigger_error(__METHOD__ . '() is deprecated; use getErrors() instead.', E_USER_DEPRECATED);
-		return $this->errors();
+		return $this->getErrors();
 	}
 
 
@@ -584,7 +585,7 @@ class Form extends Container
 
 	/**
 	 * Renders form to string.
-	 * @return bool  can throw exceptions? (hidden parameter)
+	 * @return can throw exceptions? (hidden parameter)
 	 * @return string
 	 */
 	public function __toString()
@@ -593,11 +594,10 @@ class Form extends Container
 			return $this->getRenderer()->render($this);
 
 		} catch (\Exception $e) {
-			if (func_get_args() && func_get_arg(0)) {
+			if (func_num_args()) {
 				throw $e;
-			} else {
-				trigger_error("Exception in " . __METHOD__ . "(): {$e->getMessage()} in {$e->getFile()}:{$e->getLine()}", E_USER_ERROR);
 			}
+			trigger_error("Exception in " . __METHOD__ . "(): {$e->getMessage()} in {$e->getFile()}:{$e->getLine()}", E_USER_ERROR);
 		}
 	}
 
@@ -625,9 +625,7 @@ class Form extends Container
 	{
 		$toggles = array();
 		foreach ($this->getControls() as $control) {
-			foreach ($control->getRules()->getToggles(TRUE) as $id => $hide) {
-				$toggles[$id] = empty($toggles[$id]) ? $hide : TRUE;
-			}
+			$toggles = $control->getRules()->getToggleStates($toggles);
 		}
 		return $toggles;
 	}
