@@ -324,7 +324,7 @@ class DefaultFormRenderer extends Nette\Object implements Nette\Forms\IFormRende
 	public function renderControls($parent)
 	{
 		if (!($parent instanceof Nette\Forms\Container || $parent instanceof Nette\Forms\ControlGroup)) {
-			throw new Nette\InvalidArgumentException("Argument must be FormContainer or FormGroup instance.");
+			throw new Nette\InvalidArgumentException('Argument must be FormContainer or FormGroup instance.');
 		}
 
 		$container = $this->getWrapper('controls container');
@@ -389,7 +389,7 @@ class DefaultFormRenderer extends Nette\Object implements Nette\Forms\IFormRende
 		$s = array();
 		foreach ($controls as $control) {
 			if (!$control instanceof Nette\Forms\IControl) {
-				throw new Nette\InvalidArgumentException("Argument must be array of IFormControl instances.");
+				throw new Nette\InvalidArgumentException('Argument must be array of IFormControl instances.');
 			}
 			$description = $control->getOption('description');
 			if ($description instanceof Html) {
@@ -406,7 +406,7 @@ class DefaultFormRenderer extends Nette\Object implements Nette\Forms\IFormRende
 		}
 		$pair = $this->getWrapper('pair container');
 		$pair->add($this->renderLabel($control));
-		$pair->add($this->getWrapper('control container')->setHtml(implode(" ", $s)));
+		$pair->add($this->getWrapper('control container')->setHtml(implode(' ', $s)));
 		return $pair->render(0);
 	}
 
