@@ -2,11 +2,7 @@
 
 /**
  * This file is part of the Nette Framework (http://nette.org)
- *
  * Copyright (c) 2004 David Grudl (http://davidgrudl.com)
- *
- * For the full copyright and license information, please view
- * the file license.txt that was distributed with this source code.
  */
 
 namespace Nette\Forms;
@@ -19,7 +15,7 @@ use Nette;
  *
  * @author     David Grudl
  */
-final class Rule extends Nette\Object
+class Rule extends Nette\Object
 {
 	/** type */
 	const CONDITION = 1;
@@ -27,9 +23,6 @@ final class Rule extends Nette\Object
 	/** type */
 	const VALIDATOR = 2;
 
-	/** type */
-	const FILTER = 3;
-
 	/** @var IControl */
 	public $control;
 
