@@ -143,7 +143,7 @@ class CoreMacros extends MacroSet
 		$ifNode = $node->parentNode;
 		if ($ifNode && $ifNode->name === 'if' && $ifNode->data->capture) {
 			if (isset($ifNode->data->else)) {
-				throw new CompileException("Macro {if} supports only one {else}.");
+				throw new CompileException('Macro {if} supports only one {else}.');
 			}
 			$ifNode->data->else = TRUE;
 			return 'ob_start()';
@@ -157,7 +157,7 @@ class CoreMacros extends MacroSet
 	 */
 	public function macroIfContent(MacroNode $node, PhpWriter $writer)
 	{
-		if (!$node->htmlNode) {
+		if (!$node->prefix) {
 			throw new CompileException("Unknown macro {{$node->name}}, use n:{$node->name} attribute.");
 		} elseif ($node->prefix !== MacroNode::PREFIX_NONE) {
 			throw new CompileException("Unknown attribute n:{$node->prefix}-{$node->name}, use n:{$node->name} attribute.");
@@ -176,9 +176,9 @@ class CoreMacros extends MacroSet
 		$node->content = $parts[1]
 			. '<?php ob_start() ?>'
 			. $parts[2]
-			. '<?php $_ifcontent = ob_get_length(); ob_end_flush() ?>'
+			. '<?php $_ifcontent = ob_get_contents(); ob_end_flush() ?>'
 			. $parts[3];
-		return '$_ifcontent ? ob_end_flush() : ob_end_clean()';
+		return 'rtrim($_ifcontent) === "" ? ob_end_clean() : ob_end_flush()';
 	}
 
 
@@ -244,7 +244,7 @@ class CoreMacros extends MacroSet
 	 */
 	public function macroCaptureEnd(MacroNode $node, PhpWriter $writer)
 	{
-		return $node->data->variable . $writer->write(" = %modify(ob_get_clean())");
+		return $node->data->variable . $writer->write(' = %modify(ob_get_clean())');
 	}
 
 
@@ -362,7 +362,7 @@ class CoreMacros extends MacroSet
 				$var = TRUE;
 
 			} elseif ($var === NULL && $node->name === 'default' && !$tokens->isCurrent(Latte\MacroTokens::T_WHITESPACE)) {
-				throw new CompileException("Unexpected '" . $tokens->currentValue() . "' in {default $node->args}");
+				throw new CompileException("Unexpected '{$tokens->currentValue()}' in {default $node->args}");
 
 			} else {
 				$res->append($tokens->currentToken());
