@@ -309,7 +309,7 @@ if (!empty($_control->snippetMode)) {
 
 			if (empty($node->data->leave)) {
 				if ($node->name === 'snippetArea') {
-					$node->content = "<?php \$_control->snippetMode = TRUE; ?>{$node->content}<?php \$_control->snippetMode = FALSE; ?>";
+					$node->content = "<?php \$_control->snippetMode = isset(\$_snippetMode) && \$_snippetMode; ?>{$node->content}<?php \$_control->snippetMode = FALSE; ?>";
 				}
 				if (!empty($node->data->dynamic)) {
 					$node->content .= '<?php if (isset($_dynSnippets)) return $_dynSnippets; ?>';
@@ -377,7 +377,9 @@ if (!empty($_control->snippetMode)) {
 	 */
 	public function macroLink(MacroNode $node, PhpWriter $writer)
 	{
-		return $writer->write('echo %escape(%modify(' . ($node->name === 'plink' ? '$_presenter' : '$_control') . '->link(%node.word, %node.array?)))');
+		$node->modifiers = preg_replace('#\|safeurl\s*(?=\||\z)#i', '', $node->modifiers);
+		return $writer->using($node, $this->getCompiler())
+			->write('echo %escape(%modify(' . ($node->name === 'plink' ? '$_presenter' : '$_control') . '->link(%node.word, %node.array?)))');
 	}
 
 
@@ -463,6 +465,7 @@ if (!empty($_control->snippetMode)) {
 			throw new Nette\InvalidStateException("Cannot include undefined parent block '$name'.");
 		}
 		$block($context, $params);
+		prev($context->blocks[$name]);
 	}
 
 
@@ -477,7 +480,7 @@ if (!empty($_control->snippetMode)) {
 				}
 				ob_start();
 				$function = reset($function);
-				$snippets = $function($local, $params);
+				$snippets = $function($local, $params + array('_snippetMode' => TRUE));
 				$payload->snippets[$id = $control->getSnippetId(substr($name, 1))] = ob_get_clean();
 				if ($snippets !== NULL) { // pass FALSE from snippetArea
 					if ($snippets) {
