@@ -64,7 +64,9 @@ class GlobalFunction extends \ReflectionFunction
 
 	public function getClosure()
 	{
-		return $this->isClosure() ? $this->value : NULL;
+		return PHP_VERSION_ID < 50400
+			? Nette\Utils\Callback::closure($this->value)
+			: parent::getClosure();
 	}
 
 
