@@ -114,7 +114,7 @@ class Permission extends Nette\Object implements IAuthorizator
 	private function checkRole($role, $need = TRUE)
 	{
 		if (!is_string($role) || $role === '') {
-			throw new Nette\InvalidArgumentException("Role must be a non-empty string.");
+			throw new Nette\InvalidArgumentException('Role must be a non-empty string.');
 
 		} elseif ($need && !isset($this->roles[$role])) {
 			throw new Nette\InvalidStateException("Role '$role' does not exist.");
@@ -294,7 +294,7 @@ class Permission extends Nette\Object implements IAuthorizator
 	private function checkResource($resource, $need = TRUE)
 	{
 		if (!is_string($resource) || $resource === '') {
-			throw new Nette\InvalidArgumentException("Resource must be a non-empty string.");
+			throw new Nette\InvalidArgumentException('Resource must be a non-empty string.');
 
 		} elseif ($need && !isset($this->resources[$resource])) {
 			throw new Nette\InvalidStateException("Resource '$resource' does not exist.");
