@@ -35,6 +35,7 @@ class Helpers
 		'reverse' =>  'Nette\Utils\Strings::reverse',
 		'replacere' => 'Nette\Utils\Strings::replace',
 		'url' => 'rawurlencode',
+		'escapeurl' => 'rawurlencode',
 		'striptags' => 'strip_tags',
 		'substr' => 'Nette\Utils\Strings::substring',
 		'repeat' => 'str_repeat',
@@ -69,9 +70,13 @@ class Helpers
 	 */
 	public static function escapeHtml($s, $quotes = ENT_QUOTES)
 	{
-		if (is_object($s) && ($s instanceof ITemplate || $s instanceof Html || $s instanceof Form)) {
+		if ($quotes === ENT_NOQUOTES && ($s instanceof ITemplate || $s instanceof Html || $s instanceof Form)) {
 			return $s->__toString(TRUE);
 		}
+		$s = (string) $s;
+		if ($quotes !== ENT_NOQUOTES && strpos($s, '`') !== FALSE && strpbrk($s, ' <>"\'') === FALSE) {
+			$s .= ' ';
+		}
 		return htmlSpecialChars($s, $quotes);
 	}
 
@@ -83,7 +88,11 @@ class Helpers
 	 */
 	public static function escapeHtmlComment($s)
 	{
-		return ' ' . str_replace('-', '- ', $s); // dash is very problematic character in comments
+		$s = (string) $s;
+		if ($s && ($s[0] === '-' || $s[0] === '>' || $s[0] === '!')) {
+			$s = ' ' . $s;
+		}
+		return str_replace('-', '- ', $s); // dash is very problematic character in comments
 	}
 
 
@@ -146,7 +155,7 @@ class Helpers
 	 */
 	public static function safeUrl($s)
 	{
-		return preg_match('#^(https?://.+|ftp://.+|mailto:.+|[^:]+)\z#i', $s) ? $s : '';
+		return preg_match('~^(?:(?:https?|ftp)://[^@]+(?:/.*)?|mailto:.+|[/?#].*|[^:]+)\z~i', $s) ? $s : '';
 	}
 
 
@@ -188,7 +197,7 @@ class Helpers
 
 	/**
 	 * Date/time formatting.
-	 * @param  string|int|DateTime
+	 * @param  string|int|DateTime|DateInterval
 	 * @param  string
 	 * @return string
 	 */
@@ -202,6 +211,10 @@ class Helpers
 			$format = self::$dateFormat;
 		}
 
+		if ($time instanceof \DateInterval) {
+			return $time->format($format);
+		}
+
 		$time = Nette\DateTime::from($time);
 		return Strings::contains($format, '%')
 			? strftime($format, $time->format('U')) // formats according to locales
