@@ -26,10 +26,7 @@ class Json
 		JSON_ERROR_STATE_MISMATCH => 'Syntax error, malformed JSON',
 		JSON_ERROR_CTRL_CHAR => 'Unexpected control character found',
 		JSON_ERROR_SYNTAX => 'Syntax error, malformed JSON',
-		5 /*JSON_ERROR_UTF8*/ => 'Invalid UTF-8 sequence',
-		6 /*JSON_ERROR_RECURSION*/ => 'Recursion detected',
-		7 /*JSON_ERROR_INF_OR_NAN*/ => 'Inf and NaN cannot be JSON encoded',
-		8 /*JSON_ERROR_UNSUPPORTED_TYPE*/ => 'Type is not supported',
+		5 /*JSON_ERROR_UTF8*/ => 'Invalid UTF-8 sequence', // exists since 5.3.3, but is returned since 5.3.1
 	);
 
 
@@ -50,24 +47,27 @@ class Json
 	 */
 	public static function encode($value, $options = 0)
 	{
-		if (function_exists('ini_set')) { // workaround for PHP bugs #52397, #54109, #63004
-			$old = ini_set('display_errors', 0); // needed to receive 'Invalid UTF-8 sequence' error
+		if (PHP_VERSION_ID < 50500) {
+			set_error_handler(function($severity, $message) { // needed to receive 'recursion detected' error
+				restore_error_handler();
+				throw new JsonException($message);
+			});
 		}
-		set_error_handler(function($severity, $message) { // needed to receive 'recursion detected' error
-			restore_error_handler();
-			throw new JsonException($message);
-		});
+
 		$json = json_encode(
 			$value,
 			PHP_VERSION_ID >= 50400 ? (JSON_UNESCAPED_UNICODE | ($options & self::PRETTY ? JSON_PRETTY_PRINT : 0)) : 0
 		);
-		restore_error_handler();
-		if (isset($old)) {
-			ini_set('display_errors', $old);
+
+		if (PHP_VERSION_ID < 50500) {
+			restore_error_handler();
 		}
 		if ($error = json_last_error()) {
-			throw new JsonException(isset(static::$messages[$error]) ? static::$messages[$error] : 'Unknown error', $error);
+			$message = isset(static::$messages[$error]) ? static::$messages[$error]
+				: (PHP_VERSION_ID >= 50500 ? json_last_error_msg() : 'Unknown error');
+			throw new JsonException($message, $error);
 		}
+
 		$json = str_replace(array("\xe2\x80\xa8", "\xe2\x80\xa9"), array('\u2028', '\u2029'), $json);
 		return $json;
 	}
@@ -93,7 +93,7 @@ class Json
 		}
 		$value = call_user_func_array('json_decode', $args);
 
-		if ($value === NULL && $json !== '' && strcasecmp($json, 'null')) { // '' do not clean json_last_error
+		if ($value === NULL && $json !== '' && strcasecmp($json, 'null')) { // '' is not clearing json_last_error
 			$error = json_last_error();
 			throw new JsonException(isset(static::$messages[$error]) ? static::$messages[$error] : 'Unknown error', $error);
 		}
