@@ -48,11 +48,10 @@ class Strings
 	public static function fixEncoding($s, $encoding = 'UTF-8')
 	{
 		// removes xD800-xDFFF, x110000 and higher
-		if (PHP_VERSION_ID >= 50400) {
-			ini_set('mbstring.substitute_character', 'none');
-			return mb_convert_encoding($s, $encoding, $encoding);
+		if (PHP_VERSION_ID < 50400 || strcasecmp($encoding, 'UTF-8')) {
+			return @iconv('UTF-16', $encoding . '//IGNORE', iconv($encoding, 'UTF-16//IGNORE', $s)); // intentionally @
 		} else {
-			return @iconv('UTF-16', 'UTF-8//IGNORE', iconv($encoding, 'UTF-16//IGNORE', $s)); // intentionally @
+			return htmlspecialchars_decode(htmlspecialchars($s, ENT_NOQUOTES | ENT_IGNORE, 'UTF-8'), ENT_NOQUOTES);
 		}
 	}
 
@@ -166,6 +165,9 @@ class Strings
 	{
 		$s = preg_replace('#[^\x09\x0A\x0D\x20-\x7E\xA0-\x{2FF}\x{370}-\x{10FFFF}]#u', '', $s);
 		$s = strtr($s, '`\'"^~', "\x01\x02\x03\x04\x05");
+		$s = str_replace(array("\xE2\x80\x9E", "\xE2\x80\x9C", "\xE2\x80\x9D", "\xE2\x80\x9A",
+			"\xE2\x80\x98", "\xE2\x80\x99", "\xC2\xBB", "\xC2\xAB"),
+			array("\x03", "\x03", "\x03", "\x02", "\x02", "\x02", ">>", "<<"), $s);
 		if (ICONV_IMPL === 'glibc') {
 			$s = @iconv('UTF-8', 'WINDOWS-1250//TRANSLIT', $s); // intentionally @
 			$s = strtr($s, "\xa5\xa3\xbc\x8c\xa7\x8a\xaa\x8d\x8f\x8e\xaf\xb9\xb3\xbe\x9c\x9a\xba\x9d\x9f\x9e"
@@ -409,9 +411,20 @@ class Strings
 		}, $charlist));
 		$chLen = strlen($charlist);
 
-		static $rand3;
-		if (!$rand3) {
-			$rand3 = md5(serialize($_SERVER), TRUE);
+		if (function_exists('openssl_random_pseudo_bytes')
+			&& (PHP_VERSION_ID >= 50400 || !defined('PHP_WINDOWS_VERSION_BUILD')) // slow in PHP 5.3 & Windows
+		) {
+			$rand3 = openssl_random_pseudo_bytes($length);
+		}
+		if (empty($rand3) && function_exists('mcrypt_create_iv') && (PHP_VERSION_ID !== 50303 || !defined('PHP_WINDOWS_VERSION_BUILD'))) { // PHP bug #52523
+			$rand3 = mcrypt_create_iv($length, MCRYPT_DEV_URANDOM);
+		}
+		if (empty($rand3) && @is_readable('/dev/urandom')) {
+			$rand3 = file_get_contents('/dev/urandom', FALSE, NULL, -1, $length);
+		}
+		if (empty($rand3)) {
+			static $cache;
+			$rand3 = $cache ?: $cache = md5(serialize($_SERVER), TRUE);
 		}
 
 		$s = '';
