@@ -149,12 +149,14 @@ class Image extends Object
 	 * Opens image from file.
 	 * @param  string
 	 * @param  mixed  detected image format
+	 * @throws Nette\NotSupportedException if gd extension is not loaded
+	 * @throws UnknownImageFileException if file not found or file type is not known
 	 * @return Image
 	 */
 	public static function fromFile($file, & $format = NULL)
 	{
 		if (!extension_loaded('gd')) {
-			throw new NotSupportedException("PHP extension GD is not loaded.");
+			throw new NotSupportedException('PHP extension GD is not loaded.');
 		}
 
 		$info = @getimagesize($file); // @ - files smaller than 12 bytes causes read error
@@ -197,7 +199,7 @@ class Image extends Object
 	public static function fromString($s, & $format = NULL)
 	{
 		if (!extension_loaded('gd')) {
-			throw new NotSupportedException("PHP extension GD is not loaded.");
+			throw new NotSupportedException('PHP extension GD is not loaded.');
 		}
 
 		$format = static::getFormatFromString($s);
@@ -216,7 +218,7 @@ class Image extends Object
 	public static function fromBlank($width, $height, $color = NULL)
 	{
 		if (!extension_loaded('gd')) {
-			throw new NotSupportedException("PHP extension GD is not loaded.");
+			throw new NotSupportedException('PHP extension GD is not loaded.');
 		}
 
 		$width = (int) $width;
@@ -539,7 +541,7 @@ class Image extends Object
 				return imagegif($this->getImageResource(), $file);
 
 			default:
-				throw new InvalidArgumentException("Unsupported image type.");
+				throw new InvalidArgumentException('Unsupported image type.');
 		}
 	}
 
@@ -566,8 +568,10 @@ class Image extends Object
 	{
 		try {
 			return $this->toString();
-
 		} catch (\Exception $e) {
+			if (func_num_args()) {
+				throw $e;
+			}
 			trigger_error("Exception in " . __METHOD__ . "(): {$e->getMessage()} in {$e->getFile()}:{$e->getLine()}", E_USER_ERROR);
 		}
 	}
@@ -582,7 +586,7 @@ class Image extends Object
 	public function send($type = self::JPEG, $quality = NULL)
 	{
 		if ($type !== self::GIF && $type !== self::PNG && $type !== self::JPEG) {
-			throw new InvalidArgumentException("Unsupported image type.");
+			throw new InvalidArgumentException('Unsupported image type.');
 		}
 		header('Content-Type: ' . image_type_to_mime_type($type));
 		return $this->save(NULL, $quality, $type);
@@ -621,6 +625,14 @@ class Image extends Object
 		return parent::__call($name, $args);
 	}
 
+
+	public function __clone()
+	{
+		ob_start();
+		imagegd2($this->getImageResource());
+		$this->setImageResource(imagecreatefromstring(ob_get_clean()));
+	}
+
 }
 
 
